@@ -24,25 +24,38 @@
 #include <Phonon>
 #include <QtGui>
 
+//default values
 const int ACCELEROMETER_POLL_MSEC = 500;
 const int ACCELEROMETER_THRESHOLD = 40;
+const QString SOUND_FILE = "/home/user/MyDocs/.sounds/Ringtones/Beep.aac";
+const float VOLUME = 1.0;
+const int INACTIVITY_TIMEOUT = 4; //seconds before noise will restart after device has stopped moving
+const int ALARM_TIMEOUT = 5; //minutes the device is armed after initial alarm
+
 
 class Alarm : public QDialog {
 	Q_OBJECT
 public:
-	Alarm(QWidget *parent);
+	Alarm(QWidget *parent, bool testing = false);
 	~Alarm();
+	static void test(QWidget *parent, QString sound_filename, float max_vol, int al_timeout, int in_timeout);
+protected:
+	void closeEvent(QCloseEvent*);
 private slots:
 	void accelUpdate(int, int, int);
+	void repeatSound();
 private:
 	void grabZoomKeys(bool grab);
+	void start();
 
 	QLabel *label;
 	Accelerometer *accel;
 	Phonon::MediaObject* noise;
 	Phonon::AudioOutput* audio_output;
+	QTime alarm_started;
 	int alarm_timeout, inactivity_timeout;
 	float max_volume;
 	QString old_profile;
+	bool testing;
 };
 #endif
